=======
History
=======

0.2.0 (2017-02-26)
------------------

* Improved "Usage" documentation
* Changed format of confiuration file from JSON to standard python
  configuration file (.ini)
* Added "balance" command
* Added "explore" command

0.1.0 (2017-02-21)
------------------

* First release on PyPI
